import logging
import logging.handlers
from dataEngine import AppConfig


def init_logger():
    logging.basicConfig(format=u'[%(asctime)s] [%(levelname)-8s] [%(filename)s:%(lineno)d] %(message)s',
                        level=logging.DEBUG if AppConfig.get("full_debug") else logging.WARNING)

    grey = "\033[38;1m"
    green = "\033[32;21m"
    yellow = "\033[33;21m"
    red = "\033[31;21m"
    bold_red = "\033[31;1m"
    reset = "\033[0m"
    format = "%s"

    FORMATS = {
        logging.DEBUG: green + format + reset,
        logging.INFO: yellow + format + reset,
        logging.WARNING: bold_red + format + reset,
        logging.ERROR: red + format + reset,
        logging.CRITICAL: bold_red + format + reset
    }

    for key in FORMATS.keys():
        logging.addLevelName(key, FORMATS[key] % logging.getLevelName(key))

    logger = logging.getLogger("pbxdataengine")
    s_handler = logging.handlers.SysLogHandler(address='/dev/log')
    s_format = logging.Formatter('%(name)s: <%(levelname)s>  %(message)s')
    s_handler.setFormatter(s_format)
    logger.addHandler(s_handler)
